Events
======

.. toctree::

   reference_asymptotic
   reference_event
   reference_event_duo
   reference_event_pivot_strict
   reference_event_pivot_tij
   reference_event_pivot_tjk
   reference_event_pivot_weak
   reference_event_trio
   reference_event_trio_1t
   reference_event_trio_2t
